Index: editor/tools/plugins/com.google.dart.tools.debug.ui/src/com/google/dart/tools/debug/ui/launch/DartRunLastHandler.java |
=================================================================== |
--- editor/tools/plugins/com.google.dart.tools.debug.ui/src/com/google/dart/tools/debug/ui/launch/DartRunLastHandler.java (revision 6439) |
+++ editor/tools/plugins/com.google.dart.tools.debug.ui/src/com/google/dart/tools/debug/ui/launch/DartRunLastHandler.java (working copy) |
@@ -20,15 +20,15 @@ |
import org.eclipse.ui.PlatformUI; |
/** |
* A command handler to invoke the run action. |
*/ |
-public class DartRunHandler extends AbstractHandler { |
- private DartRunAction runAction; |
+public class DartRunLastHandler extends AbstractHandler { |
+ private DartRunLastAction runLastAction; |
/** |
* Create a new DartRunHandler. |
*/ |
- public DartRunHandler() { |
+ public DartRunLastHandler() { |
} |
@@ -39,12 +39,13 @@ |
return null; |
} |
- private DartRunAction getRunAction() { |
- if (runAction == null) { |
- runAction = new DartRunAction(PlatformUI.getWorkbench().getActiveWorkbenchWindow(), true); |
+ private DartRunLastAction getRunAction() { |
+ if (runLastAction == null) { |
+ runLastAction = new DartRunLastAction(PlatformUI.getWorkbench().getActiveWorkbenchWindow(), |
+ true); |
} |
- return runAction; |
+ return runLastAction; |
} |
} |
@@ -20,15 +20,15 @@ |
import org.eclipse.ui.PlatformUI; |
/** |
- * A command handler to invoke the run action. |
+ * A command handler to invoke the run last action. |
*/ |